summaryrefslogtreecommitdiff
path: root/dbaccess/source/ui/inc/TableConnectionData.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'dbaccess/source/ui/inc/TableConnectionData.hxx')
-rw-r--r--dbaccess/source/ui/inc/TableConnectionData.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/dbaccess/source/ui/inc/TableConnectionData.hxx b/dbaccess/source/ui/inc/TableConnectionData.hxx
index ec85e99dc825..79ccd802d564 100644
--- a/dbaccess/source/ui/inc/TableConnectionData.hxx
+++ b/dbaccess/source/ui/inc/TableConnectionData.hxx
@@ -78,14 +78,14 @@ namespace dbaui
virtual OTableConnectionData* NewInstance() const;
// (von OTableConnectionData abgeleitete Klasse muessen entsprechend eine Instanz ihrer Klasse liefern)
- BOOL SetConnLine( USHORT nIndex, const String& rSourceFieldName, const String& rDestFieldName );
- BOOL AppendConnLine( const ::rtl::OUString& rSourceFieldName, const ::rtl::OUString& rDestFieldName );
- void ResetConnLines( BOOL bUseDefaults = TRUE );
+ sal_Bool SetConnLine( sal_uInt16 nIndex, const String& rSourceFieldName, const String& rDestFieldName );
+ sal_Bool AppendConnLine( const ::rtl::OUString& rSourceFieldName, const ::rtl::OUString& rDestFieldName );
+ void ResetConnLines( sal_Bool bUseDefaults = sal_True );
/** normalizeLines moves the empty lines to the back
*/
void normalizeLines();
// loescht die Liste der ConnLines, bei bUseDefaults == TRUE werden danach MAX_CONN_COUNT neue Dummy-Linien eingefuegt
OConnectionLineDataVec* GetConnLineDataList(){ return &m_vConnLineData; }
@@ -102,7 +102,7 @@ namespace dbaui
@return true if successful
*/
- virtual BOOL Update(){ return TRUE; }
+ virtual sal_Bool Update(){ return sal_True; }
};
typedef ::std::vector< ::boost::shared_ptr<OTableConnectionData> > TTableConnectionData;
@@ -78,14 +78,14 @@ namespace dbaui
*/
void normalizeLines();
- // loescht die Liste der ConnLines, bei bUseDefaults == TRUE werden danach MAX_CONN_COUNT neue Dummy-Linien eingefuegt
+ // loescht die Liste der ConnLines, bei bUseDefaults == sal_True werden danach MAX_CONN_COUNT neue Dummy-Linien eingefuegt
OConnectionLineDataVec* GetConnLineDataList(){ return &m_vConnLineData; }